@@ -1,7 +1,7 @@
 package Bencher::Formatter::DeleteConstantFields;
 
 our $DATE = '2016-06-17'; # DATE
-our $VERSION = '1.009'; # VERSION
+our $VERSION = '1.010'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,6 +11,7 @@ use warnings;
 use parent qw(Bencher::Formatter);
 
 use Role::Tiny::With;
+with 'Bencher::Role::FieldMunger';
 with 'Bencher::Role::ResultMunger';
 
 sub munge_result {
@@ -24,9 +25,7 @@ sub munge_result {
         my @const_cols = $td->const_col_names;
         for my $k (@const_cols) {
             next unless $k =~ /^(item_.+|arg_.+|perl|modver|participant|dataset)$/;
-            for my $row (@{ $envres->[2] }) {
-                delete $row->{$k};
-            }
+            $self->delete_fields($envres, $k);
         }
     }
 }
@@ -46,7 +45,7 @@ Bencher::Formatter::DeleteConstantFields - Delete constant item permutation fiel
 
 =head1 VERSION
 
-This document describes version 1.009 of Bencher::Formatter::DeleteConstantFields (from Perl distribution Bencher-Backend), released on 2016-06-17.
+This document describes version 1.010 of Bencher::Formatter::DeleteConstantFields (from Perl distribution Bencher-Backend), released on 2016-06-17.
 
 =head1 DESCRIPTION
 
